@@ -1,13 +1,11 @@
 from .useful_functions import wordlist_divider
 from .useful_functions import merge_wordlists
 from .useful_functions import import_module_from_path
-from .useful_functions import get_wordlists
+from .useful_functions import import_function_from_script
+from .useful_functions import get_wordlist_from_path
+from .useful_functions import get_wordlists_from_paths
 from .useful_functions import get_arguments
 from .useful_functions import read_file_lines
 from .useful_functions import pure_bruteforce_rule
 from .useful_functions import custom_product
-
-
-class Modes(object):
-    WORDLIST_BLOCK = 0
-    BASIC_MODE = 1
+from .useful_functions import arguments_queue_handler
